@@ -1,8 +1,7 @@
 """
 Parses data from MAL,Anilist and themes.moe
 """
-from .anilist import get_anilist
+from .animelist import ANIMELISTSITES ,AniList, MyAnimeList
 from .animethemes import fetch_animethemes
 from .dldata import get_download_data
-from .myanimelist import get_mal
 from .parser import get_animethemes
